@@ -1,12 +1,9 @@
-import inspect
 import json
 import os
 import random
 import re
 from datetime import date, datetime, time, timedelta, timezone
-from functools import lru_cache
 from urllib.parse import urlparse
-from . import temp
 
 import jwt
 import requests
@@ -14,6 +11,7 @@ from dotenv import load_dotenv
 from url_remote.environment_name_enum import EnvironmentName
 
 from .mini_logger import MiniLogger as logger
+from .temp import deprecation_warning
 
 load_dotenv()
 # TODO Let's do brainstorming on this
@@ -34,22 +32,22 @@ DEFAULT_DATETIME_FORMAT = "%Y-%m-%d %H:%M:%S"
 
 
 def append_if_not_exist(lst: list, item: object) -> None:
-    temp.deprecation_warning("append_if_not_exist","DELETE",date(2024,7,25))
+    deprecation_warning("append_if_not_exist", "DELETE", date(2024, 6, 5))
     if item not in lst:
         lst.append(item)
 
 
 def to_dict(data: json or dict or None) -> dict:
-    temp.deprecation_warning("to_dict","DELETE",date(2024,7,25))
+    deprecation_warning("to_dict", "DELETE", date(2024, 6, 5))
     if data is None:
         return {}
     if isinstance(data, dict):
         return data
-    return json.loads(data)
+    return json.loads(data)  # TODO: replace all `return statement` with `return identifier`
 
 
 def to_json(data: json or dict or None) -> json:
-    temp.deprecation_warning("to_json","DELETE",date(2024,7,25))
+    deprecation_warning("to_json", "DELETE", date(2024, 6, 5))
     if data is None:
         data = {}
     if isinstance(data, dict):
@@ -58,7 +56,7 @@ def to_json(data: json or dict or None) -> json:
 
 
 def timedelta_to_time_format(time_delta: timedelta) -> str:
-    temp.deprecation_warning("timedelta_to_time_format","DELETE",date(2024,7,25))
+    deprecation_warning("timedelta_to_time_format", "DELETE", date(2024, 6, 5))
     """
     Convert a timedelta to a time format in HH:MM:SS.
 
@@ -95,7 +93,7 @@ def timedelta_to_time_format(time_delta: timedelta) -> str:
 
 
 def is_valid_time_range(time_range: tuple) -> bool:
-    temp.deprecation_warning("is_valid_time_range","DELETE",date(2024,7,25))
+    deprecation_warning("is_valid_time_range", "DELETE", date(2024, 6, 5))
     """
     Validate that the time range is in the format 'HH:MM:SS'.
     """
@@ -122,7 +120,7 @@ def is_valid_time_range(time_range: tuple) -> bool:
 # TODO shall we also use Url type and not only str? - Strongly Type which I prefer
 #   (if yes we should change it also in all the calls to this function)
 def validate_url(url: str):
-    temp.deprecation_warning("validate_url","DELETE",date(2024,7,25))
+    deprecation_warning("validate_url", "DELETE", date(2024, 6, 5))
     logger.start(object={"url": url})
     if url is not None or url != "":
         parsed_url = urlparse(url)
@@ -134,7 +132,7 @@ def validate_url(url: str):
 
 
 def is_valid_date_range(date_range: tuple) -> bool:
-    temp.deprecation_warning("is_valid_date_range","DELETE",date(2024,7,25))
+    deprecation_warning("is_valid_date_range", "DELETE", date(2024, 6, 5))
     """
     Validate that the date range is in the format 'YYYY-MM-DD'.
     """
@@ -153,7 +151,7 @@ def is_valid_date_range(date_range: tuple) -> bool:
 
 
 def is_valid_datetime_range(datetime_range: (datetime, datetime)) -> bool:
-    temp.deprecation_warning("is_valid_datetime_range","DELETE",date(2024,7,25))
+    deprecation_warning("is_valid_datetime_range", "DELETE", date(2024, 6, 5))
     """
     Validate that the datetime range is in the format 'YYYY-MM-DD HH:MM:SS'.
     """
@@ -171,7 +169,7 @@ def is_valid_datetime_range(datetime_range: (datetime, datetime)) -> bool:
 
 
 def is_list_of_dicts(obj: object) -> bool:
-    temp.deprecation_warning("is_list_of_dicts","DELETE",date(2024,7,25))
+    deprecation_warning("is_list_of_dicts", "DELETE", date(2024, 6, 5))
     """
     Check if an object is a list of dictionaries.
 
@@ -216,7 +214,7 @@ def is_list_of_dicts(obj: object) -> bool:
 
 
 def is_time_in_time_range(check_time: time, time_range: tuple) -> bool:
-    temp.deprecation_warning("is_time_in_time_range","DELETE",date(2024,7,25))
+    deprecation_warning("is_time_in_time_range", "DELETE", date(2024, 6, 5))
     """
     Check if the given time is within the specified time range.
 
@@ -240,7 +238,7 @@ def is_time_in_time_range(check_time: time, time_range: tuple) -> bool:
 
 
 def is_date_in_date_range(check_date: date, date_range: tuple) -> bool:
-    temp.deprecation_warning("is_date_in_date_range","DELETE",date(2024,7,25))
+    deprecation_warning("is_date_in_date_range", "DELETE", date(2024, 6, 5))
     """
     Check if the given date is within the specified date range.
 
@@ -265,7 +263,7 @@ def is_date_in_date_range(check_date: date, date_range: tuple) -> bool:
 
 
 def is_datetime_in_datetime_range(check_datetime: datetime, datetime_range: (datetime, datetime)) -> bool:
-    temp.deprecation_warning("is_datetime_in_datetime_range","DELETE",date(2024,7,25))
+    deprecation_warning("is_datetime_in_datetime_range", "DELETE", date(2024, 6, 5))
     """
     Check if the given datetime is within the specified datetime range.
 
@@ -329,7 +327,7 @@ def get_dialog_jwt_secret_key() -> str:
 
 
 def encode_jwt(payload: dict, key: str) -> str:
-    temp.deprecation_warning("encode_jwt","DELETE",date(2024,7,25))
+    deprecation_warning("encode_jwt", "DELETE", date(2024, 6, 5))
     """Example:
     payload = {
         "user_id": 123,
@@ -341,7 +339,7 @@ def encode_jwt(payload: dict, key: str) -> str:
 
 
 def decode_jwt(token: str, key: str) -> dict:
-    temp.deprecation_warning("decode_jwt","DELETE",date(2024,7,25))
+    deprecation_warning("decode_jwt", "DELETE", date(2024, 6, 5))
     """key can be private / public"""
     return jwt.decode(token, key, algorithms=['HS256'])
 
@@ -377,35 +375,35 @@ def obfuscate_log_dict(log_dict: dict) -> dict:
 # TODO: add tests to the following functions
 
 def remove_digits(text: str) -> str:
-    temp.deprecation_warning("remove_digits","DELETE",date(2024,7,25))
+    deprecation_warning("remove_digits", "DELETE", date(2024, 6, 5))
     return ''.join(i for i in text if not i.isdigit())
 
 
 def generate_otp():
-    temp.deprecation_warning("generate_otp","DELETE",date(2024,7,25))
+    deprecation_warning("generate_otp", "DELETE", date(2024, 6, 5))
     """Generates a 6-digit OTP"""
     otp = random.randint(100000, 999999)
     return otp
 
 
 def get_current_datetime_string(datetime_format: str = DEFAULT_DATETIME_FORMAT, tz: timezone = None) -> str:
-    temp.deprecation_warning("get_current_datetime_string","DELETE",date(2024,7,25))
+    deprecation_warning("get_current_datetime_string", "DELETE", date(2024, 6, 5))
     current_datetime_string = datetime.now(tz).strftime(datetime_format)
     return current_datetime_string
 
 
 def datetime_from_str(date_str: str, datetime_format: str = DEFAULT_DATETIME_FORMAT) -> datetime:
-    temp.deprecation_warning("datetime_from_str","DELETE",date(2024,7,25))
+    deprecation_warning("datetime_from_str", "DELETE", date(2024, 6, 5))
     return datetime.strptime(date_str, datetime_format)
 
 
 def datetime_to_str(input_datetime: datetime, datetime_format: str = DEFAULT_DATETIME_FORMAT) -> str:
-    temp.deprecation_warning("datetime_to_str","DELETE",date(2024,7,25))
+    deprecation_warning("datetime_to_str", "DELETE", date(2024, 6, 5))
     return input_datetime.strftime(datetime_format)
 
 
 def validate_arguments(args: dict) -> None:
-    temp.deprecation_warning("validate_arguments","DELETE",date(2024,7,25))
+    deprecation_warning("validate_arguments", "DELETE", date(2024, 6, 5))
     """
     Validate method arguments to ensure they are not None or ''
     :param args: arguments to be validated (usually locals())
@@ -417,7 +415,7 @@ def validate_arguments(args: dict) -> None:
 
 
 def reformat_time_string(input_str: str) -> str:
-    temp.deprecation_warning("reformat_time_string","DELETE",date(2024,7,25))
+    deprecation_warning("reformat_time_string", "DELETE", date(2024, 6, 5))
     """Example:
     "1234" -> "12:34:00:00"
     """
@@ -431,12 +429,12 @@ def reformat_time_string(input_str: str) -> str:
 
 
 def get_ip_v4():
-    temp.deprecation_warning("get_ip_v4","DELETE",date(2024,7,25))
+    deprecation_warning("get_ip_v4", "DELETE", date(2024, 6, 5))
     return requests.get('https://ipv4.seeip.org/jsonip').json()['ip']
 
 
 def get_ip_v6():
-    temp.deprecation_warning("get_ip_v6","DELETE",date(2024,7,25))
+    deprecation_warning("get_ip_v6", "DELETE", date(2024, 6, 5))
     return requests.get('https://api.seeip.org/jsonip').json()['ip']
 
 
@@ -451,5 +449,3 @@ def camel_to_snake(camel_str: str) -> str:
     """Converts camelCase to snake_case."""
     snake_str = re.sub(r'(?<!^)(?=[A-Z])', '_', camel_str).lower()
     return snake_str
-
-
